#!/usr/bin/env node

var path = require('path');
var fs = require('fs-extra');
var commander = require('commander')
var chalk = require('chalk');
var spawn = require('cross-spawn');
// var validateProjectName = require("validate-npm-package-name");

var projectName;
commander.usage('<app-name>')
  .action(function(name) {
    projectName = name;
  })

commander.on('--help', function() {
  console.log('  Examples:')
  console.log()
  console.log(chalk.gray('    # create a new project with an official template'))
  console.log('    $ zaro init my-app')
  console.log()
})

function help() {
  commander.parse(process.argv)
  if (commander.args.length < 1) return commander.help()
}
help()


var currentNodeVersion = process.versions.node;
if (currentNodeVersion.split('.')[0] < 6) {
  console.error(
    chalk.red(
      'You are running Node ' + currentNodeVersion + '.\n' +
      'Zaro requires Node 6 or higher. \n' +
      'Please update your version of Node.'
    )
  );
  process.exit(1);
}


create(projectName);

function create(name) {
  var projectPath = path.resolve(name);
  fs.ensureDirSync(name);
  console.log('Createing a new Zaro project named ' + name + ' in ' + projectPath);

  var packageJson = {
    name: name,
    version: '0.1.0',
    private: true,
    dependencies: {
      "zaro": require('../package').version
    },
    scripts: {
      "start": "webpack-dev-server --config webpack.local.js"
    }
  }
  fs.writeFileSync(
    path.join(projectPath, 'package.json'),
    JSON.stringify(packageJson, null, 2)
  );


  console.log('Installing ' + chalk.cyan('Zaro') + ' and dependent packages');
  process.chdir(projectPath);
  new Promise(function(resolve, reject) {
    var command = 'npm';
    var args = ['install'];
    var child = spawn(command, args, { stdio: 'inherit' });
    child.on('close', function(code) {
      if (code !== 0) {
        reject({
          command: command + ' ' + args.join(' ')
        });
        return;
      }
      resolve();
    })
  }).then(function () {
    console.log('Package installing succeed!')
    console.log(projectPath)
    spawn('cp', ['-R', projectPath + '/node_modules/zaro/example/', './'], { stdio: 'inherit' });
  }).catch(function () {
    console.log(chalk.red('Package installing failed'));
  });
}
