import { Templates, Components, utils } from 'zaro';
import { openTab } from '../../utils/common';

const { ListPage } = Templates;
const { Toaster, Modal } = Components;
const searchCondition = [{
  type: 'text',
  key: 'channelLoanOrderId',
  text: '借款订单号',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'channelUserId',
  text: '用户编号',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'mobile',
  text: '用户手机号',
  maxLength: 11,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'identNo',
  text: '用户身份证',
  maxLength: 20,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'loanProductId',
  text: '贷款产品ID',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'select',
  key: 'channelBankId',
  text: '银行渠道',
  options: [{
    value: '', text: '请选择'
  }, {
    value: 'jingu', text: '金谷农商行'
  }]
}, {
  type: 'select',
  key: 'orderStatus',
  text: '订单状态',
  options: [{
    value: '', text: '请选择'
  }, {
    value: '00', text: '全部'
  }, {
    value: '02', text: '审批中'
  }, {
    value: '03', text: '待签约'
  }, {
    value: '04', text: '待放款'
  }, {
    value: '06', text: '放款成功'
  }, {
    value: '07', text: '审批失败'
  }, {
    value: '08', text: '放弃签约'
  }, {
    value: '09', text: '放款失败'
  }]
}, {
  type: 'timePickerRange',
  text: '借款申请时间',
  key: 'applyTime',
  items: [{
    key: 'applyTimeStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'applyTimeEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}, {
  type: 'timePickerRange',
  text: '审批通过时间',
  key: 'approvedTime',
  items: [{
    key: 'approvedTimeStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'approvedTimeEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}, {
  type: 'timePickerRange',
  text: '签约时间',
  key: 'agreementSignTime',
  items: [{
    key: 'agreementSignTimeStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'agreementSignTimeEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}, {
  type: 'timePickerRange',
  text: '放款时间',
  key: 'paySuccessTime',
  items: [{
    key: 'paySuccessTimeStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'paySuccessTimeEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}];

const listFormat = [{
  key: 'channelLoanOrderId',
  title: '借款单号'
}, {
  key: 'channelUserId',
  title: '用户编号'
}, {
  key: 'userName',
  title: '用户名'
}, {
  key: 'mobile',
  title: '用户手机号',
}, {
  key: 'identNo',
  title: '用户身份证',
}, {
  key: 'loanProductId',
  title: '贷款产品ID',
}, {
  key: 'applyLoanAmount',
  title: '申请贷款金额',
}, {
  key: 'approvedLoanAmount',
  title: '批复金额',
}, {
  key: 'channelBankId',
  title: '银行渠道',
  format: {
    '01': 'jingu',
    jingu: '金谷农商行'
  }
}, {
  key: 'organizationName',
  title: '所属组织',
}, {
  key: 'orderStatus',
  title: '订单状态',
  format: {
    '02': '审批中',
    '03': '待签约',
    '04': '待放款',
    '06': '放款成功',
    '07': '审批失败',
    '08': '放弃签约',
    '09': '放款失败',
  }
}, {
  key: 'applyTime',
  title: '借款申请时间',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}];

const operations = [{
  text: '查看',
  func: (idx, item) => {
    const orderId = item.channelLoanOrderId;
    const bankId = item.channelBankId;
    const userId = item.channelUserId;
    openTab('借款单详情', orderId, `credit/loanProductDetail.html?id=${orderId}&bankId=${bankId}&userId=${userId}`);
  },
  auth: 'detail',
}];

function getExport(searchData) {
  utils.fetch('/api/bosscredit/loanOrder/export', {
    method: 'POST',
    data: searchData,
    headers: {
      token: localStorage.getItem('token'),
      userId: localStorage.getItem('userId')
    }
  }).then((res) => {
    console.log(res.data);
    const msgType = (res.code === '0000') ? 'success' : 'error';
    if (res.code === '0000') {
      const a = document.createElement('a');
      document.body.appendChild(a);
      a.href = res.data;
      a.download = 'down';
      a.target = '_blank';
      a.click();
    } else {
      Toaster.toaster({ type: msgType, content: res.message, time: 3000 });
    }
  }, (error) => {
    Toaster.toaster({ type: 'error', content: (error && error.message) || '获取数据错误', time: 3000 });
  });
}

const buttons = [{
  text: '查询',
  func: 'search',
  type: 'primary'
}, {
  text: '导出',
  func(searchData) {
    console.log(searchData);
    Modal.confirm({ tirtle: '提示', content: '是否确认导出?' }, () => { getExport(searchData); }, () => { console.log('this is cancle callback'); });
  }
}];

ListPage({
  searchCondition,
  searchUrl: '/api/bosscredit/loanOrder/list',
  buttons,
  operations,
  listFormat
});
