import { Templates, Components, utils } from 'zaro';
import { closeTab } from '../../utils/common';

const { RichDetailPage } = Templates;
const { Toaster } = Components;

const baseInfo = [{
  text: '借款单号',
  key: 'channelLoanOrderId'
}, {
  key: 'orderStatus',
  text: '订单状态'
}, {
  key: 'channelBankId',
  text: '银行渠道',
  format: { jingu: '金谷农商行' }
}, {
  key: 'organizationName',
  text: '所属组织'
}, {
  key: 'channelUserId',
  text: '用户编号'
}, {
  text: '用户名',
  key: 'userName'
}, {
  text: '用户手机号',
  key: 'mobile',
}, {
  text: '用户身份证',
  key: 'identNo',
}, {
  text: '银行卡号',
  key: 'bindingBankCardNo'
}, {
  text: '月收入',
  key: 'monthSalary'
}, {
  text: '籍贯',
  key: 'nativePlaceDistrict'
}, {
  text: '学历',
  key: 'education'
}, {
  text: '婚姻状况',
  key: 'marriageStatus'
}, {
  text: '居住类型',
  key: 'liveType'
}, {
  text: '居住地区',
  key: 'cityDistrict'
}, {
  text: '详细地址',
  key: 'detailAddress'
}, {
  text: '联系人关系',
  key: 'contactRelation'
}, {
  text: '联系人姓名',
  key: 'contactName'
}, {
  text: '联系人手机',
  key: 'contactMobile'
}, {
  text: '联系人地址',
  key: 'contactDetailAddress'
}, {
  text: '常用银行卡号',
  key: 'commonUsedDebitCardNo'
}];

const loanInfo = [{
  key: 'loanProductId',
  text: '贷款产品id'
}, {
  key: 'loanProductName',
  text: '贷款产品名称'
}, {
  key: 'repaymentMethod',
  text: '还款方式',
  format: {
    '00': '等额本息',
    '01': '等额本金',
    '02': '到期一次性还本付息',
    '03': '按月付息到期还本',
    '04': '一次付息到期还本'
  }
}, {
  key: 'applyLoanAmount',
  text: '申请借款金额'
}, {
  key: 'fixedLoanInterestMonthRate',
  text: '申请产品固定月利率'
}, {
  text: '申请期限',
  key: 'applyLoanTerm'
}, {
  text: '借款申请时间',
  key: 'applyTime',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  text: '批复金额',
  key: 'approvedLoanAmount',
}, {
  text: '批复利率',
  key: 'approvedLoanInterestMonthRate'
}, {
  text: '批复期限',
  key: 'approvedLoanTerm'
}, {
  text: '批复时间',
  key: 'approvedTime',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  text: '签约金额',
  key: 'agreementLoanAmount'
}, {
  text: '签约利率',
  key: 'agreementLoanInterestMonthRate'
}, {
  text: '签约期限',
  key: 'agreementLoanTerm'
}, {
  text: '签约时间',
  key: 'agreementSignTime',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  text: '应还本金加利息',
  key: 'repayTotal'
}, {
  text: '应还本金',
  key: 'repayPrincipleTotal'
}, {
  text: '应还利息',
  key: 'repayInterestTotal'
}, {
  text: '应还服务费+违约金',
  key: 'repayFeeTotal'
}];

const repayPlanList = [{
  key: 'repaymentOrderId',
  title: '还款订单号'
}, {
  key: 'shouldRepayAmount',
  title: '每期应还总金额'
}, {
  key: 'shouldRepayPrinciple',
  title: '每期应还本金'
}, {
  key: 'shouldRepayInterest',
  title: '每期应还利息',
}, {
  key: 'shouldRepayServiceFee',
  title: '每期应还服务费',
}, {
  key: 'shouldRepayDeadline',
  title: '应还时间',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  key: 'orderStatus',
  title: '子订单状态',
  format: {
    '02': '审批中',
    '03': '待签约',
    '04': '待放款',
    '06': '放款成功',
    '07': '审批失败',
    '08': '放弃签约',
    '09': '放款失败',
  }
}, {
  key: 'actualRepayAmount',
  title: '实际还款金额',
}, {
  key: 'actualRepayFinishedTime',
  title: '实际还款时间',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}];

const btns = [{
  text: '关闭',
  action: () => {
    closeTab();
  }
}];


const detailData = [{
  key: 'baseInfo',
  titlePart: {
    title: '基础信息',
    note: ''
  },
  data: baseInfo,
  templateType: 'template'
}, {
  key: 'loanInfo',
  titlePart: {
    title: '贷款产品信息',
    note: ''
  },
  data: loanInfo,
  templateType: 'template'
}, {
  key: 'repayPlanList',
  titlePart: {
    title: '还款计划表',
    note: ''
  },
  data: repayPlanList,
  templateType: 'table'
}];
console.log(utils.getUrlParam().id, utils.getUrlParam().bankId, utils.getUrlParam().userId);

utils.fetch('/api/bosscredit/loanOrder/id', {
  method: 'GET',
  data: {
    channelLoanOrderId: utils.getUrlParam().id,
    channelBankId: utils.getUrlParam().bankId,
    channelUserId: utils.getUrlParam().userId
  },
  headers: {
    token: localStorage.getItem('token'),
    userId: localStorage.getItem('userId')
  }
}).then((res) => {
  console.log(res.data);
  const msgType = (res.code === '0000') ? 'success' : 'error';
  if (res.code === '0000') {
    RichDetailPage({
      detailData,
      respData: res.data,
      btns
    });
  } else {
    Toaster.toaster({ type: msgType, content: res.message, time: 3000 });
  }
}, (error) => {
  Toaster.toaster({ type: 'error', content: (error && error.message) || '获取数据错误', time: 3000 });
});
