import { Templates, Components, utils } from 'zaro';
import { openTab } from '../../utils/common';

const { ListPage } = Templates;
const { Toaster, Modal } = Components;
const searchCondition = [{
  type: 'text',
  key: 'channelLoanOrderId',
  text: '借款订单号',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'repaymentOrderId',
  text: '还款单号',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'channelUserId',
  text: '用户编号',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'mobile',
  text: '用户手机号',
  maxLength: 11,
  maxLengthShow: false,
}, {
  type: 'text',
  key: 'loanProductId',
  text: '贷款产品ID',
  maxLength: 30,
  maxLengthShow: false,
}, {
  type: 'select',
  key: 'channelBankId',
  text: '银行渠道',
  options: [{
    value: '', text: '请选择'
  }, {
    value: 'jingu', text: '金谷农商行'
  }]
}, {
  type: 'select',
  key: 'orderStatus',
  text: '借款单状态',
  options: [{
    value: '', text: '请选择'
  }, {
    value: '10', text: '全部'
  }, {
    value: '00', text: '待还款'
  }, {
    value: '01', text: '已还款'
  }, {
    value: '02', text: '已逾期'
  }, {
    value: '03', text: '已坏账'
  }, {
    value: '04', text: '已部分还款'
  }, {
    value: '05', text: '已逾期坏账'
  }, {
    value: '06', text: '坏账收款'
  }]
}, {
  type: 'timePickerRange',
  text: '应还时间',
  key: 'shouldRepayDeadlineTime',
  items: [{
    key: 'shouldRepayDeadlineStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'shouldRepayDeadlineEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}, {
  type: 'timePickerRange',
  text: '实际还款时间',
  key: 'actualRepayFinishedTime',
  items: [{
    key: 'actualRepayFinishedTimeStart',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
    after: '-'
  }, {
    key: 'actualRepayFinishedTimeEnd',
    type: 'date',
    dateFormat: 'YYYY-MM-DD HH:mm:ss',
    timeFormat: 'HH:mm:ss',
    style: {
      width: '180px'
    },
  }]
}];

const listFormat = [{
  key: 'channelLoanOrderId',
  title: '借款单号'
}, {
  key: 'repaymentOrderId',
  title: '还款单号'
}, {
  key: 'channelUserId',
  title: '用户编号'
}, {
  key: 'mobile',
  title: '用户手机号',
}, {
  key: 'loanProductId',
  title: '贷款产品ID',
}, {
  key: 'shouldRepayAmount',
  title: '应还总金额',
}, {
  key: 'alreadyRepayAmount',
  title: '实际还款金额',
}, {
  key: 'channelBankId',
  title: '银行渠道',
  format: {
    '01': 'jingu',
    jingu: '金谷农商行'
  }
}, {
  key: 'orderStatus',
  title: '还款单状态',
  format: {
    '00': '待还款',
    '01': '已还款',
    '02': '已逾期',
    '03': '已坏账',
    '04': '已部分还款',
    '05': '已逾期坏账',
    '06': '坏账收款',
  },
  options: [{ value: '00', text: '待还款' },
  { value: '01', text: '已还款' },
  { value: '02', text: '已逾期' },
  { value: '03', text: '已坏账' },
  { value: '04', text: '已部分还款' },
  { value: '05', text: '已逾期坏账' },
  { value: '06', text: '坏账收款' }]
}, {
  key: 'shouldRepayDeadline',
  title: '应还时间',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  key: 'actualRepayFinishedTime',
  title: '实际还款完成时间',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}];

const operations = [{
  text: '查看',
  func: (idx, item) => {
    const id = item.repaymentOrderId;
    openTab('还款单详情', id, `credit/repaymentProductDetail.html?id=${id}`);
  },
  auth: 'detail',
}];
function getExport(searchData) {
  utils.fetch('/api/bosscredit/loanOrder/export', {
    method: 'POST',
    data: searchData,
    headers: {
      token: localStorage.getItem('token'),
      userId: localStorage.getItem('userId')
    }
  }).then((res) => {
    console.log(res.data);
    const msgType = (res.code === '0000') ? 'success' : 'error';
    if (res.code === '0000') {
      const a = document.createElement('a');
      document.body.appendChild(a);
      a.href = res.data;
      a.download = 'down';
      a.target = '_blank';
      a.click();
    } else {
      Toaster.toaster({ type: msgType, content: res.message, time: 3000 });
    }
  }, (error) => {
    Toaster.toaster({ type: 'error', content: (error && error.message) || '获取数据错误', time: 3000 });
  });
}
const buttons = [{
  text: '查询',
  func: 'search',
  type: 'primary'
}, {
  text: '导出',
  func(searchData) {
    console.log(searchData);
    Modal.confirm({ tirtle: '提示', content: '是否确认导出?' }, () => { getExport(searchData); }, () => { console.log('this is cancle callback'); });
  }
}];

ListPage({
  searchCondition,
  searchUrl: '/api/bosscredit/repayOrder/list',
  buttons,
  operations,
  listFormat
});
