import { Templates, Components, utils } from 'zaro';
import { closeTab } from '../../utils/common';

const { RichDetailPage } = Templates;
const { Toaster } = Components;

const repayInfo = [{
  text: '借款单号',
  key: 'channelLoanOrderId'
}, {
  key: 'repaymentOrderId',
  text: '还款单号'
}, {
  key: 'channelBankId',
  text: '银行渠道',
  format: { jingu: '金谷农商行' }
}, {
  key: 'organizationName',
  text: '所属组织'
}, {
  key: 'channelUserId',
  text: '用户编号'
}, {
  text: '用户手机号',
  key: 'mobile',
}, {
  key: 'loanProductId',
  text: '贷款产品编号'
}, {
  key: 'orderStatus',
  text: '订单状态'
}, {
  text: '应还总金额',
  key: 'shouldRepayAmount'
}, {
  text: '应还本金',
  key: 'shouldRepayPrinciple'
}, {
  text: '应还利息',
  key: 'shouldRepayInterest'
}, {
  text: '应还服务费',
  key: 'shouldRepayServiceFee'
}, {
  text: '应还罚息',
  key: 'shouldRepayLateFee'
}, {
  text: '实际还款金额',
  key: 'alreadyRepayAmount'
}, {
  text: '应还时间',
  key: 'shouldRepayDeadline',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}, {
  text: '实际还款时间',
  key: 'actualRepayFinishedTime',
  format: ['date', 'yyyy-MM-dd hh:mm:ss']
}];

const repayOrderList = [{
  key: 'actualRepayFinishedTime',
  title: '支付时间'
}, {
  key: 'alreadyRepayAmount',
  title: '支付金额'
}, {
  key: 'orderStatus',
  title: '支付状态'
}];

const btns = [{
  text: '关闭',
  action: () => {
    closeTab();
  }
}];


const detailData = [{
  key: 'repayInfo',
  titlePart: {
    title: '还款详情',
    note: ''
  },
  data: repayInfo,
  templateType: 'template'
}, {
  key: 'repayOrderList',
  titlePart: {
    title: '已还款列表',
    note: ''
  },
  data: repayOrderList,
  templateType: 'table'
}];
// console.log(utils.getUrlParam().id);

utils.fetch('/api/bosscredit/repayOrder/id', {
  method: 'GET',
  data: {
    repaymentOrderId: utils.getUrlParam().id
  },
  headers: {
    token: localStorage.getItem('token'),
    userId: localStorage.getItem('userId')
  }
}).then((res) => {
  console.log(res.data);
  const msgType = (res.code === '0000') ? 'success' : 'error';
  if (res.code === '0000') {
    RichDetailPage({
      detailData,
      respData: res.data,
      btns
    });
  } else {
    Toaster.toaster({ type: msgType, content: res.message, time: 3000 });
  }
}, (error) => {
  Toaster.toaster({ type: 'error', content: (error && error.message) || '获取数据错误', time: 3000 });
});
