const webpack = require('webpack');
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const OpenBrowserPlugin = require('open-browser-webpack-plugin');

process.env.NODE_ENV = 'production';

module.exports = {
  entry: {
    main: './example/src/index.js',
    zaro: ['react', 'react-dom', 'zaro']
    // zaro: 'zaro'
  },
  output: {
    filename: '[name].[chunkhash].js',
    path: path.resolve(__dirname, 'build')
  },
  plugins: [
    new CleanWebpackPlugin('build'),
    new webpack.optimize.CommonsChunkPlugin({
      name: 'zaro',
      minChunks: Infinity,
      filename: 'zaro.js'
    }),

    new HtmlWebpackPlugin({

      title: 'test',
      template: 'src/template/basic.html'
    }),

    new OpenBrowserPlugin({
      url: 'http://localhost:8000'
    }),

  ],
  module: {
    rules: [{
      test: /\.(js|jsx)$/,
      exclude: /node_modules/,
      use: [
        'babel-loader'
      ]
    }, {
      test: /\.(css|scss)$/,
      exclude: /node_modules/,
      use: [
        'style-loader',
        'css-loader',
        'sass-loader'
      ]
    }, {
      test: /(\.jp(e)g|\.png|\.gif|\.svg)$/,
      exclude: /node_modules/,
      use: {
        loader: 'file-loader',
        query: {
          name: '[name].[ext]'
        },
      }
    }]
  },
  resolve: {
    alias: {
      zaro: path.resolve(__dirname, '../dist/zaro')
    }
  }
};
