// const webpack = require('webpack');
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const WebpackSftpClient = require('webpack-sftp-client');
const fs = require('fs');
const env = require('yargs').argv.env;

process.env.NODE_ENV = 'production';

const getEntry = () => {
  const basePath = `${__dirname}/src/page/`;
  return {
    jsEntry: fs.readdirSync(basePath).reduce((map, dirName) => {
      map[dirName] = `${basePath}${dirName}/index.js`;
      return map;
    }, {
      zaro: ['react', 'react-dom', 'zaro']
    }),
    HtmlWebpackPlugin: fs.readdirSync(basePath).map(dirName => new HtmlWebpackPlugin({
      filename: `html/${dirName}.html`,
      chunks: [dirName, 'zaro'],
      title: dirName,
      template: 'example/src/template/basic.html',
    }))
  };
};

let envPlugin = [];
let publicPath = '';
if (env === 'dev2') {
  envPlugin = [
    new WebpackSftpClient({
      port: '22',
      host: '10.24.248.181',
      username: 'root',
      password: 'xxxxx',
      path: path.resolve(__dirname, 'dist'),
      remotePath: '/data/website/admin/boss/credit/',
      verbose: true
    })
  ];
  publicPath = '//o4jh53fw9.qnssl.com/dev2/admin/boss/credit/app/';
} else if (env === 'test2') {
  envPlugin = [
    new WebpackSftpClient({
      port: '22',
      host: '10.43.1.10',
      username: 'root',
      password: 'xxxxxxxxx',
      path: path.resolve(__dirname, 'dist'),
      remotePath: '/data/website2/admin/boss/credit/',
      verbose: true
    })
  ];
  publicPath = '//o4jh53fw9.qnssl.com/test2/admin/boss/credit/app/';
}

const plugins = [
  new CleanWebpackPlugin('dist'),
].concat(envPlugin).concat(getEntry().HtmlWebpackPlugin);

module.exports = {
  entry: getEntry().jsEntry,
  output: {
    filename: '[name].[chunkhash].js',
    path: path.resolve(__dirname, 'dist'),
    publicPath
  },
  plugins,
  module: {
    rules: [{
      test: /\.(js|jsx)$/,
      exclude: /node_modules/,
      use: [
        'babel-loader'
      ]
    }, {
      test: /\.css$/,
      exclude: /node_modules/,
      use: [
        'style-loader',
        'css-loader'
      ]
    }, {
      test: /(\.jp(e)g|\.png|\.gif|\.svg)$/,
      exclude: /node_modules/,
      use: {
        loader: 'file-loader',
        query: {
          name: '[name].[ext]'
        },
      }
    }]
  },
  resolve: {
    alias: {
      zaro: path.resolve(__dirname, '../src/index')
    }
  },
  devtool: 'source-map'
};
