import React, { Component } from 'react';
import { PropTypes } from 'prop-types';
import styles from './style';

import authFunc from '../../utils/auth';

import Loading from '../../Components/Loading';

import {
  Table,
  TableRow,
  TableRowColumn,
  TableHeaderRow,
  Pagination,
  Container,
  Button
} from '../../Components';

import filter from '../../utils/filter';

export default class TablePart extends Component {
  componentDidMount() {
    if (this.page) {
      this.search = this.page.search;
    }
  }
  getRuleArray(auth, crule, key) {
    if (!key) {
      return false;
    }
    this.auth = auth;
    let arr = [];
    for (let i = 0; i <= crule.length; i++) {
      if (crule[i] && crule[i].value && key === crule[i].value) {
        // console.log(crule[i].rule);
        arr = crule[i].rule;
        break;
      }
    }
    if (arr.indexOf(auth) < 0) {
      return false; // 该操作不在权限内
    }
    return true; // 该操作在权限内
  }
  genHeader() {
    const { itemFormat, operations } = this.props;
    const opLength =
      operations.filter(item => !item.auth || authFunc(item.auth)).length;

    const opWidth = opLength * styles.opBtnLength;
    return (
      <TableHeaderRow>
        {
          itemFormat.map((item, idx) => {
            const key = `${item.title}-${idx}`;
            return (
              <TableRowColumn
                key={key}
                columnNumber={idx}
                title={item.title}
              >{item.title}</TableRowColumn>
            );
          })
        }
        {
          opLength ?
            <TableRowColumn style={{ width: opWidth }} columnNumber={opLength}>
              操作
            </TableRowColumn>
          :
            ''
        }
      </TableHeaderRow>
    );
  }
  genOperations(rowIdx, item) {
    const { operations, items, operationsRule } = this.props;
    const relyKey = item[operationsRule.relyKey];
    const crule = operationsRule.crule;
    // console.log(operationsRule.crule, item[operationsRule.relyKey]);

    const map = {
      add: '新增',
      delete: '删除',
      dateil: '查看',
      update: '编辑',
    };
    // 操作对象不存在，return null
    if (operations.length === 0) {
      return null;
    }
    return (
      <TableRowColumn columnNumber={1}>
        {
          operations.map((op) => {
            if (op.auth && !authFunc(op.auth)) {
              return null;
            }
            // console.log(this.getRuleArray(op.auth, crule, relyKey))
            if (crule && !this.getRuleArray(op.auth, crule, relyKey)) {
              return null;
            }
            if (op.type) {
              const func = () => {
                if (op.url) {
                  console.log(`跳转${op.url}`);
                } else {
                  op.func(rowIdx, items[rowIdx], this.search);
                }
              };
              return (
                <Button
                  key={`${rowIdx}-${op.type}`}
                  style={styles.opBtn}
                  text={map[op.type]}
                  onClick={func}
                  idx={rowIdx}
                  type={['primary', 'small']}
                />
              );
            }

            const func = () => {
              op.func(rowIdx, items[rowIdx], this.search);
            };
            return (
              <Button
                key={`${rowIdx}-${op.text}`}
                text={op.text}
                onClick={func}
                style={styles.opBtn}
                type={['primary', 'small']}
              />
            );
          })
        }
      </TableRowColumn>
    );
  }
  genRows() {
    const { items, itemFormat } = this.props;

    return items.map((item, rowIdx) => {
      const rowKey = `rowKey${rowIdx}`;
      return (
        <TableRow
          key={rowKey}
          rowNumber={rowIdx}
        >
          {
            itemFormat.map((config, colIdx) => {
              const { format, key, after } = config;
              const value = format ? filter(format, item[key]) : item[key];
              const tAfter = (value && after) ? (after) : '';
              return (
                <TableRowColumn
                  key={key}
                  columnNumber={colIdx}
                  title={value}
                >{value}{tAfter}</TableRowColumn>
              );
            })
          }
          {
            this.genOperations(rowIdx, item)
          }
        </TableRow>
      );
    });
  }
  render() {
    const {
      isLoading,
      title,
      minWidth,
      beforeSearch,
      success,
      searchParams,
      url,
      items,
      showPage
    } = this.props;

    const paginationStyle = Object.assign({}, styles.pagination);

    if (!items.length) {
      paginationStyle.display = 'none';
    }

    return (
      <div>
        {
          <Container
            title={title}
          >
            {
              isLoading ?
                <Loading />
              :
                <Table hoverable center style={minWidth ? { minWidth } : {}} >
                  {this.genHeader()}
                  {this.genRows()}
                </Table>
            }
            {
              !items.length && !isLoading ?
                <div style={styles.empty}>列表为空</div>
              :
                null
            }
            {
              showPage ?
                <Pagination
                  url={url}
                  beforeSearch={beforeSearch}
                  success={success}
                  searchParams={searchParams}
                  style={paginationStyle}
                  ref={(item) => {
                    this.page = item;
                  }}
                />
              : ''
            }
          </Container>
        }

      </div>
    );
  }
}

TablePart.propTypes = {
  title: PropTypes.string,
  url: PropTypes.string.isRequired,
  items: PropTypes.arrayOf(PropTypes.shape()).isRequired,
  itemFormat: PropTypes.arrayOf(PropTypes.shape()).isRequired,
  operations: PropTypes.arrayOf(PropTypes.shape()),
  operationsRule: PropTypes.shape(),
  isLoading: PropTypes.bool,
  minWidth: PropTypes.number,
  beforeSearch: PropTypes.func,
  success: PropTypes.func,
  searchParams: PropTypes.shape(),
  showPage: PropTypes.bool
};

TablePart.defaultProps = {
  title: '查询结果',
  url: '',
  isLoading: false,
  operations: [],
  operationsRule: {},
  minWidth: null,
  success: () => {},
  beforeSearch: () => {},
  searchParams: {},
  showPage: true
};
