import React, { Component } from 'react';
import { PropTypes } from 'prop-types';
import ReactDom from 'react-dom';

import Button from '../../Components/Button';
import * as arrayUtils from '../../utils/array';
import styles from './style';

import { DetailPart, TitlePart, TablePart } from '../../Parts';

class RichDetailTemplate extends Component {

  static mergeDetail(detailList, respData) {
    return detailList.map((info) => {
      if (info.items) {
        arrayUtils.forEach(info.items, (item) => {
          item.value = respData[item.key];
        });
      } else {
        info.value = respData[info.key];
      }

      return info;
    });
  }

  constructor() {
    super();
    this.state = {
      listData: [],
      isLoading: false,
      searchParams: null
    };
  }

  getComment(detailData, respData) {
    const AllComment = detailData.map((item) => {
      const mergedDetailList = RichDetailTemplate.mergeDetail(item.data, respData[item.key]);
      let comment = '';
      if (item.templateType === 'table') {
        comment = (
          <div style={styles.marginB} key={item.key}>
            <TablePart
              title={item.titlePart.title}
              items={respData[item.key]}
              minWidth={1200}
              itemFormat={item.data}
              showPage={false}
              ref={(items) => {
                this.table = items;
              }}
            />
          </div>);
      } else {
        comment = (
          <div style={styles.marginB} key={item.key}>
            <TitlePart titlepart={item.titlePart} />
            <DetailPart
              detailList={mergedDetailList}
              data={respData[item.key]}
              display={'half'}
            />
          </div>
        );
      }
      return comment;
    });
    return AllComment;
  }
  render() {
    const { detailData, respData, btns } = this.props;
    // const mergedDetailList = RichDetailTemplate.mergeDetail(detailData, respData);
    return (
      <div>
        {this.getComment(detailData, respData)}
        <div style={styles.container} >
          <span style={styles.text} />
          {
            btns.map(btn => (
              <Button key={btn.text} style={styles.btn} text={btn.text} onClick={btn.action} />
            ))
          }
        </div>
      </div>
    );
  }
}

RichDetailTemplate.propTypes = {
  detailData: PropTypes.arrayOf(PropTypes.shape()).isRequired,
  respData: PropTypes.shape(),
  btns: PropTypes.arrayOf(PropTypes.shape()),
};

RichDetailTemplate.defaultProps = {
  valid: [],
  btns: [],
  respData: {}
};

const render = function (props) {
  ReactDom.render(
    <RichDetailTemplate
      {...props}
    />,
    document.getElementById('root')
  );
};


export default function renderDetail(props) {
  render(props);
}
